@@ -1,12 +1,12 @@
 import os
 
-import pydmt.version
-import pylogconf.core
 import sys
 import pathlib
 
-from pytconf.config import register_function_group, register_endpoint
+import pylogconf.core
+from pytconf import register_function_group, register_endpoint
 
+import pydmt.version
 from pydmt.features.documentation import Documentation
 from pydmt.core.pydmt import PyDMT
 from pydmt.features.templating import Templating
