@@ -11,9 +11,10 @@ class Documentation(Feature):
         sphinx_folder: str = "sphinx",
     ):
         self.sphinx_folder = sphinx_folder
+        import config.project
+        self.project_name = config.project.project_name
 
     def setup(self, pydmt: PyDMT) -> None:
         if not os.path.isdir(self.sphinx_folder):
             return
-        import config.project
-        pydmt.add_builder(Sphinx(package_name=config.project.project_name))
+        pydmt.add_builder(Sphinx(package_name=self.project_name))
